==> libreoffice-4.0.5.2.tar.xz: libreoffice-4.0.5.2/svtools/source/edit/svmedit.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */



#include "unoiface.hxx"
#include <svtools/textwindowpeer.hxx>



MultiLineEdit::MultiLineEdit( Window* pParent, WinBits nWinStyle )
    : VclMultiLineEdit( pParent,nWinStyle )
{
}
MultiLineEdit::MultiLineEdit( Window* pParent, const ResId& rResId )
    : VclMultiLineEdit( pParent,rResId )
{
}

// virtual
::css::uno::Reference< ::css::awt::XWindowPeer >
MultiLineEdit::GetComponentInterface(sal_Bool bCreate)
{
    ::css::uno::Reference< ::css::awt::XWindowPeer > xPeer(
        VclMultiLineEdit::GetComponentInterface(false));
    if (!xPeer.is() && bCreate)
    {
        ::std::auto_ptr< VCLXMultiLineEdit > xVCLMEdit(new VCLXMultiLineEdit());
        xVCLMEdit->SetWindow(this);
        xPeer = xVCLMEdit.release();
        SetComponentInterface(xPeer);
    }
    return xPeer;
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_4.2.3~rc3.orig.tar.xz: libreoffice-4.2.3~rc3/svtools/source/edit/svmedit.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */



#include "unoiface.hxx"
#include <svtools/textwindowpeer.hxx>



MultiLineEdit::MultiLineEdit( Window* pParent, WinBits nWinStyle )
    : VclMultiLineEdit( pParent,nWinStyle )
{
}
MultiLineEdit::MultiLineEdit( Window* pParent, const ResId& rResId )
    : VclMultiLineEdit( pParent,rResId )
{
}

// virtual
css::uno::Reference< css::awt::XWindowPeer >
MultiLineEdit::GetComponentInterface(sal_Bool bCreate)
{
    css::uno::Reference< css::awt::XWindowPeer > xPeer(
        VclMultiLineEdit::GetComponentInterface(false));
    if (!xPeer.is() && bCreate)
    {
        ::std::auto_ptr< VCLXMultiLineEdit > xVCLMEdit(new VCLXMultiLineEdit());
        xVCLMEdit->SetWindow(this);
        xPeer = xVCLMEdit.release();
        SetComponentInterface(xPeer);
    }
    return xPeer;
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
